"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const FONT_FAMILY = _reactNative.Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const engine = (0, _engineJavascript.createJavaScriptRegexEngine)({
  forgiving: true,
  simulation: true,
  cache: new Map()
});
async function createHighlighter({
  langs,
  themes
}) {
  if (!langs?.length) {
    throw new Error('Please provide languages when creating a highlighter.');
  }
  try {
    return await (0, _core.createHighlighterCore)({
      langs,
      themes,
      engine
    });
  } catch (error) {
    console.error('Failed to create highlighter:', error);
    throw error;
  }
}
function parseColor(color) {
  if (!color) return undefined;

  // Handle hex with alpha (#RRGGBBAA)
  if (color.length === 9 && color.startsWith('#')) {
    const alpha = Number.parseInt(color.slice(7, 9), 16) / 255;
    const r = Number.parseInt(color.slice(1, 3), 16);
    const g = Number.parseInt(color.slice(3, 5), 16);
    const b = Number.parseInt(color.slice(5, 7), 16);
    return `rgba(${r}, ${g}, ${b}, ${alpha})`;
  }
  return color;
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)(null);

  // Generate styles once when theme changes
  const styles = (0, _react.useMemo)(() => {
    const backgroundColor = parseColor(theme.colors?.['editor.background']) || '#1e1e1e';
    const foregroundColor = parseColor(theme.colors?.['editor.foreground']) || '#d4d4d4';
    console.log('[SyntaxHighlighter] Theme colors:', {
      background: backgroundColor,
      foreground: foregroundColor,
      allColors: theme.colors
    });
    return _reactNative.StyleSheet.create({
      scrollView: {
        flex: 1,
        minHeight: 20
      },
      codeContainer: {
        padding: 16,
        minWidth: '100%',
        backgroundColor
      },
      lineContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap'
      },
      token: {
        fontFamily: FONT_FAMILY,
        color: foregroundColor
      }
    });
  }, [theme]);

  // Cache token styles
  const styleCache = (0, _react.useMemo)(() => new Map(), []);
  const getTokenStyle = token => {
    const key = `${token.color || ''}-${token.fontStyle || ''}`;
    if (!styleCache.has(key)) {
      styleCache.set(key, {
        color: parseColor(token.color) || styles.token.color,
        fontStyle: token.fontStyle === 2 ? 'italic' : 'normal',
        fontWeight: token.fontStyle === 1 ? 'bold' : 'normal'
      });
      console.log('[SyntaxHighlighter] Caching token style:', key, styleCache.get(key));
    }
    return styleCache.get(key);
  };

  // Highlight code when text/language changes
  (0, _react.useEffect)(() => {
    let mounted = true;
    async function highlight() {
      if (!text) {
        setTokens([]);
        return;
      }
      try {
        console.log('[SyntaxHighlighter] Creating highlighter for language:', languageId);
        const highlighter = await createHighlighter({
          langs: language ? [language] : [],
          themes: [theme]
        });
        console.log('[SyntaxHighlighter] Theme settings:', {
          settings: theme.settings,
          // Expand the first few tokenColors to see their full structure
          tokenColors: theme.tokenColors?.slice(0, 5).map(tc => ({
            scope: tc.scope,
            settings: tc.settings
          }))
        });
        const result = highlighter.codeToTokens(text, {
          lang: languageId || 'plaintext',
          theme,
          includeExplanation: true
        });

        // And let's look at the token explanation too
        console.log('[SyntaxHighlighter] First token explanation:',
        // @ts-expect-error - we know explanation exists because we asked for it
        result.tokens[0][0].explanation?.[0]);
        console.log('[SyntaxHighlighter] Result:', result);

        // Safely handle potential undefined tokens
        if (result.tokens && result.tokens.length > 0) {
          const firstLine = result.tokens[0];
          if (firstLine && firstLine.length > 0) {
            console.log('[SyntaxHighlighter] First two tokens:', firstLine.slice(0, 2).map(token => ({
              content: token.content,
              color: token.color,
              explanation: token.explanation
            })));
          }
        }
        if (mounted && result.tokens) {
          setTokens(result.tokens);
          setError(null);
        }
      } catch (err) {
        console.error('Syntax highlighting failed:', err);
        if (mounted) {
          setError(err instanceof Error ? err : new Error('Highlighting failed'));
          // Fallback to plain text display on error
          setTokens([[{
            content: text,
            color: styles.token.color,
            offset: 0
          }]]);
        }
      }
    }
    highlight();
    return () => {
      mounted = false;
    };
  }, [text, language, languageId, theme]);
  if (error) {
    // Fallback to plain text on error
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
      horizontal: true,
      ...scrollViewProps,
      style: [styles.scrollView, scrollViewProps?.style],
      contentContainerStyle: [styles.codeContainer, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: [styles.token, {
          fontSize
        }, textStyle],
        children: text
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.codeContainer, containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((line, lineIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.lineContainer,
        children: line.map((token, tokenIndex) => {
          const tokenStyle = getTokenStyle(token);
          if (lineIndex === 0 && tokenIndex === 0) {
            console.log('[SyntaxHighlighter] First token styles:', {
              base: styles.token,
              token: tokenStyle,
              fontSize,
              custom: textStyle
            });
          }
          return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
            style: [styles.token, tokenStyle, {
              fontSize
            }, textStyle],
            children: token.content
          }, `${lineIndex}-${tokenIndex}`);
        })
      }, lineIndex))
    })
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map